@@ -41,6 +41,8 @@ def decode_nulls(value):
     else:
         return value
 
+
+
 def get_ssm_path(project, application, stage, key=None, prefix=None):
     return prefix + Contexts.encode_context_path(project, application, stage, key)
 
@@ -56,7 +58,7 @@ def load_ssm_path(parameters, path, parameter_type, prefix=None, decrypt=False):
             Logger.warn("Inherited {0} '{1}' overridden.".format(ssm_resource_type[parameter_type] , key))
         
         parameters[key] = {
-                            'Value': decode_nulls(parameter['Value']), 
+                            'Value': unescape_curly_brackets(parameter['Value']) if parameter_type == 'StringList' else decode_nulls(parameter['Value']), 
                             'Path': parameter['Name'],
                             'Version': parameter['Version'],
                             'Date': parameter['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
@@ -65,7 +67,7 @@ def load_ssm_path(parameters, path, parameter_type, prefix=None, decrypt=False):
 
 
 
-def load_context_ssm_parameters(project, application, stage, parameter_type, prefix=None, decrypt=False, uninherited=False):
+def load_context_ssm_parameters(project, application, stage, parameter_type, prefix='', decrypt=False, uninherited=False):
     ### construct search path in hierachy with no key specified
     paths = Contexts.get_hierachy_context_paths(project, application, stage, key=None, prefix=prefix, allow_stages=(not stage is None), uninherited=uninherited)
     parameters = {}
