@@ -259,22 +259,6 @@ def read_data(input, parent_key, keys, format):
 #         raise DSOException(f"Multiple '{param.name}' {type(param)} is not allowd.")
 
 
-
-def validate_only_one_provided(values, names, causes=[]):
-
-    test = not reduce(lambda x, y: bool(x) != bool(y), values)
-    if test:
-        Logger.info(CLI_MESSAGES['TryHelp'], stress = False, force=True)
-        if causes:
-            raise DSOException(CLI_MESSAGES['ArgumentsOnlyOneProvidedBecause'].format(', '.join(causes), ', '.join(names)))
-        else:
-            raise DSOException(CLI_MESSAGES['ArgumentsOnlyOneProvided'].format(', '.join(names)))
-    
-    # return list(filter(lambda i: bool(values[i]), range(len(values))))
-    return reduce(lambda x, y: x or y, values)
-
-
-
 ### opposite validate_not_all_provided
 def validate_all_provided(values, names, causes=[]):
 
@@ -338,6 +322,12 @@ def validate_at_least_one_provided(values, names, causes=[]):
 
 
 
+def validate_only_one_provided(values, names, causes=[]):
+    validate_not_all_provided(values, names, causes)
+    return validate_at_least_one_provided(values, names, causes)
+
+
+
 def validate_query_argument(query, query_all, default_query):
     
     validate_not_all_provided([query, query_all], ["'-q' / '--query'", "'-a' / '--query-all'"])
