@@ -90,13 +90,13 @@ class ConfigManager:
         self.update_merged_config()
 
 
-    def load_local_config(self, show_warnings=True):
+    def load_local_config(self, silent=False):
         self.local_config_dir_path = os.path.join(self.working_dir, self.config_dir)
         self.local_config_file_path = os.path.join(self.local_config_dir_path, self.config_file)
 
         if not os.path.exists(self.local_config_file_path):
             self.local_config = {}
-            if show_warnings:
+            if not silent:
                 Logger.warn(MESSAGES['NoDSOConfigFound'])
             return
 
@@ -165,24 +165,24 @@ class ConfigManager:
 
         return result
 
-    def get_config_overrides(self, context, config_overrides_string):
+    def get_config_overrides(self, scope, config_overrides_string):
         _config = {}
-        if context == 'global':
+        if scope == 'global':
             _config['project'] = 'default'
             Logger.warn("Switched to the global context.")
-        elif context == 'project':
+        elif scope == 'project':
             _config['application'] = 'default'
-            Logger.warn(f"Switched to the project context '{self.project}'.")
-        elif context == 'application':
+            Logger.warn(f"Switched to project context '{self.project}'.")
+        elif scope == 'application':
             pass
         return merge_dicts(self.config_string_to_dict(config_overrides_string), _config)
 
-    def load(self, working_dir, context, config_overrides_string):
+    def load(self, working_dir, scope, config_overrides_string):
         self.working_dir = working_dir
         self.load_local_config()
         self.load_global_config()
         self.load_inherited_config()
-        self.override_config(self.get_config_overrides(context, config_overrides_string))
+        self.override_config(self.get_config_overrides(scope, config_overrides_string))
         self.check_version()
 
     def check_version(self):
@@ -193,18 +193,18 @@ class ConfigManager:
                 Logger.warn(MESSAGES['DSOConfigOlder'].format(_default_config['version'], self.merged_config['version']))
 
 
-    def get_provider_default_spec(self, provider_id):
-        if provider_id in sys.modules:
-            provider = sys.modules[provider_id]
+    def get_provider_default_spec(self, provider, provider_id):
+        if f'{provider}/{provider_id}' in sys.modules:
+            provider = sys.modules[f'{provider}/{provider_id}']
             # provider = __import__(provider_id)
             # provider = imp.find_module(provider_id)
             # Logger.debug(f"Providers '{provider_id}' has already been loaded.")
         else:
-            Logger.debug(f"Providers '{provider_id}' has not been loaded. Loading...")
-            providerPackagePath = os.path.join(self.install_path, 'provider', provider_id)
+            Logger.debug(f"Provider '{provider}/{provider_id}' has not been loaded. Loading...")
+            providerPackagePath = os.path.join(self.install_path, 'provider', f'{provider}/{provider_id}')
             if not os.path.exists(providerPackagePath):
-                raise DSOException(f"Providers '{provider_id}' not found.")
-            provider = imp.load_package(provider_id, providerPackagePath)
+                raise DSOException(f"Provider '{provider}/{provider_id}' not found.")
+            provider = imp.load_package(f'{provider}/{provider_id}', providerPackagePath)
         
         return provider.get_default_spec()
 
@@ -218,12 +218,13 @@ class ConfigManager:
         ### add missing default specs for each provider
         providers = ['parameter', 'secret', 'template']
         for provider in providers:
-            providerId = self.merged_config[provider]['provider']['id']
+            providerId = self.get_provider_id(provider)
             if providerId:
-                save = self.merged_config[provider]['provider']['spec'].copy()
-                self.merged_config[provider]['provider']['spec'] = self.get_provider_default_spec(f"{provider}/{providerId}")
+                save = self.get_provider_spec(provider).copy()
+                self.merged_config[provider]['provider']['spec'] = self.get_provider_default_spec(provider, providerId)
                 merge_dicts(save, self.merged_config[provider]['provider']['spec'])
 
+
     def flush_local_config(self):
         os.makedirs(self.local_config_dir_path, exist_ok=True)
         with open(self.local_config_file_path, 'w') as outfile:
@@ -235,87 +236,103 @@ class ConfigManager:
             yaml.dump(self.global_config, outfile, sort_keys=False, indent=2)
 
     @property
-    def application(self):
-        if 'application' in self.merged_config:
-            result = self.merged_config['application'] or 'default'
+    def project(self):
+        if 'project' in self.overriden_config:
+            result = self.overriden_config['project'].lower() or 'default'
+        
+        elif 'project' in self.local_config:
+            result = self.local_config['project'].lower() or 'default'
+
+        elif 'DSO_PROJECT' in os.environ:
+            result = os.getenv('DSO_PROJECT').lower() or 'default'
+
+        elif 'project' in self.merged_config:
+            result = self.merged_config['project'].lower() or 'default'
+
         else:
-            result  = os.getenv('DSO_APPLICATION') or 'default'
-        if self.project == 'default':
-            if not result == 'default':
-                # Logger.warn(f"Switched to project context '{self.project}' '{result}'.")
-                Logger.debug(f"The application context '{result}' was reset because the global context is being used.")
-                result = 'default'
-        return result.lower()
+            result = 'default'
+
+        return result
+
 
     @property
-    def project(self):
-        if 'project' in self.merged_config:
-            result = self.merged_config['project'] or 'default'
+    def application(self):
+        if 'application' in self.overriden_config:
+            result = self.overriden_config['application'].lower() or 'default'
+        
+        elif 'application' in self.local_config:
+            result = self.local_config['application'].lower() or 'default'
+
+        elif 'DSO_APPLICATION' in os.environ:
+            result = os.getenv('DSO_APPLICATION').lower() or 'default'
+
+        elif 'application' in self.merged_config:
+            result = self.merged_config['application'].lower() or 'default'
+        
         else:
-            result  = os.getenv('DSO_PROJECT') or 'default'
-        # if result == 'default':
-        #         Logger.warn(f"The global context is being used.")
-        return result.lower()
+            result = 'default'
+        
+        if not result == 'default' and self.project == 'default':
+            Logger.debug(f"Application '{result}' was ignored because the global context is being used.")
+            result = 'default'
+
+        return result
+
+
+    def get_provider_id(self, provider):
+        try:
+            result = self.merged_config[provider]['provider']['id'] or os.getenv(f"DSO_{provider.upper()}_PROVIDER_ID")
+        except KeyError:
+            raise DSOException("Invalid dso configuration schema.")
+        return result
 
     @property
     def parameter_provider(self):
-        try:
-            result = self.merged_config['parameter']['provider']['id']
-        except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Parameter'))
-        return result
+        return self.get_provider_id('parameter')
+
+    # @parameter_provider.setter
+    # def parameter_provider(self, value):
+    #     self.merged_config['parameter']['provider']['id'] = value
 
     @property
     def secret_provider(self):
-        try:
-            result = self.merged_config['secret']['provider']['id']
-        except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Secret'))
-        return result
+        return self.get_provider_id('secret')
+
+    # @secret_provider.setter
+    # def secret_provider(self, value):
+    #     self.merged_config['secret']['provider']['id'] = value
 
     @property
     def template_provider(self):
+        return self.get_provider_id('template')
+
+    # @template_provider.setter
+    # def template_provider(self, value):
+    #     self.merged_config['template']['provider']['id'] = value
+
+    def get_provider_spec(self, provider, key=None):
         try:
-            result = self.merged_config['template']['provider']['id']
+            result = self.merged_config[provider]['provider']['spec']
         except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
-        return result
+            raise DSOException("Invalid dso configuration schema.")
+        if not key:
+            return result
+        elif key in result:
+            return result[key]
+        else:
+            return ''
 
     def parameter_spec(self, key=None):
-        try:
-            result = self.merged_config['parameter']['provider']['spec']
-        except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Parameter'))
-        if not key:
-            return result
-        elif key in result:
-            return result[key]
-        else:
-            return None
+        return self.get_provider_spec('parameter', key)
+
 
     def secret_spec(self, key=None):
-        try:
-            result = self.merged_config['secret']['provider']['spec']
-        except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Secret'))
-        if not key:
-            return result
-        elif key in result:
-            return result[key]
-        else:
-            return None
+        return self.get_provider_spec('secret', key)
+
 
     def template_spec(self, key):
-        try:
-            result = self.merged_config['template']['provider']['spec']
-        except KeyError:
-            raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
-        if not key:
-            return result
-        elif key in result:
-            return result[key]
-        else:
-            return None
+        return self.get_provider_spec('template', key)
+
 
     def get_template_render_paths(self, key=None):
         result = get_dict_item(self.local_config, ['template', 'render']) or {}
@@ -418,11 +435,11 @@ class ConfigManager:
             ### merge with existing local configuration?
             if use_local:
                 Logger.debug("Merging local configuration...")
-                self.load_local_config(False)
+                self.load_local_config(True)
                 config = merge_dicts(self.local_config, config)
         else:
             ### do not show warning if directory is not initialized yet
-            self.load_local_config(False)
+            self.load_local_config(True)
             config = merge_dicts(self.local_config, config)
             ### override locally inherited configuration?
             if use_local: 
