@@ -1,4 +1,5 @@
 
+import os
 from .logger import Logger
 from .exceptions import DSOException
 
@@ -10,7 +11,7 @@ def clean_directory(path):
             rmtree(path)
 
 
-###--------------------------------------------------------------------------------------------
+
 
 def is_binary_file(filename):
     """ 
@@ -23,3 +24,7 @@ def is_binary_file(filename):
             if b'\0' in block:
                 return True
     return False
+
+
+def exists_on_path(filename):
+    return any([os.path.exists(os.path.join(p, filename)) for p in os.environ.get('PATH', '').split(os.pathsep)])
\ No newline at end of file
