@@ -6,6 +6,7 @@ import contextlib
 from subprocess import Popen, PIPE
 from .logger import Logger
 from .settings import *
+from .file_utils import *
 
 def get_pager():
     if platform.system() == 'Windows':
@@ -13,6 +14,7 @@ def get_pager():
     else:
         return PosixPager()
 
+
 @contextlib.contextmanager
 def ignore_ctrl_c():
     original = signal.signal(signal.SIGINT, signal.SIG_IGN)
@@ -30,9 +32,7 @@ class PagerBase(object):
     PAGER = None
 
     def get_pager_cmdline(self):
-        pager = self.PAGER
-        if 'PAGER' in os.environ:
-            pager = os.environ['PAGER']
+        pager = os.getenv('DSO_PAGER') or self.PAGER
         return pager.split(' ')
 
     def page(self, contents):
@@ -44,6 +44,11 @@ class PagerBase(object):
 
     def _send_output_to_pager(self, output):
         cmdline = self.get_pager_cmdline()
+        if not exists_on_path(cmdline[0]):
+            Logger.debug(f"Pager '{cmdline[0]}' not found in PATH.")
+            self.output_stream.write(output.decode('utf-8') + "\n")
+            self.output_stream.flush()
+            return
         p = self._popen(cmdline, stdin=PIPE)
         p.communicate(input=output)
 
@@ -60,7 +65,7 @@ class PosixPager(PagerBase):
 
     def _send_output_to_pager(self, output):
         cmdline = self.get_pager_cmdline()
-        if not self._exists_on_path(cmdline[0]):
+        if not exists_on_path(cmdline[0]):
             Logger.debug(f"Pager '{cmdline[0]}' not found in PATH.")
             self.output_stream.write(output.decode('utf-8') + "\n")
             self.output_stream.flush()
@@ -69,10 +74,6 @@ class PosixPager(PagerBase):
             p = self._popen(cmdline, stdin=PIPE)
             p.communicate(input=output)
 
-    def _exists_on_path(self, name):
-        return any([os.path.exists(os.path.join(p, name))
-                    for p in os.environ.get('PATH', '').split(os.pathsep)])
-
 class WindowsPager(PagerBase):
 
     PAGER = 'more'
