@@ -35,7 +35,6 @@ class AwsSsmParameterProvider(ParameterProvider):
         return Configs.parameter_spec('prefix')
 
 
-
     def list(self, project, application, stage, uninherited=False, filter=None):
         parameters = load_context_ssm_parameters(project, application, stage, 'String', prefix=self.get_prefix(), uninherited=uninherited)
         result = {'Parameters': []}
@@ -90,14 +89,13 @@ class AwsSsmParameterProvider(ParameterProvider):
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found['Name']}")
         response = get_ssm_parameter_history(found['Name'])
-        parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        parameters = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         if revision is None:
             ### get the latest revision
             result = {
                     'RevisionId': str(parameters[0]['Version']),
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    # 'Value': decode_nulls(parameters[0]['Value']),
                     'Value': parameters[0]['Value'],
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
@@ -113,7 +111,7 @@ class AwsSsmParameterProvider(ParameterProvider):
                     'RevisionId':str(parameters[0]['Version']),
                     'Date': parameters[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': decode_nulls(parameters[0]['Value']),
+                    'Value': parameters[0]['Value'],
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -134,13 +132,13 @@ class AwsSsmParameterProvider(ParameterProvider):
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found['Name']}")
         response = get_ssm_parameter_history(found['Name'])
-        parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        parameters = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         result = { "Revisions":
             [{
                 'RevisionId': str(parameter['Version']),
                 'Date': parameter['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 # 'Key': key,
-                'Value': decode_nulls(parameter['Value']),
+                'Value': parameter['Value'],
                 # 'Scope': found['Scope'],
                 # 'Origin': found['Origin'],
                 'User': parameter['LastModifiedUser'],
