@@ -82,7 +82,7 @@ class AwsSsmSecretProvider(SecretProvider):
 
 
 
-    def get(self, project, application, stage, key, revision=None, decrypt=False):
+    def get(self, project, application, stage, key, decrypt=False, revision=None):
         Logger.debug(f"Locating SSM secret: project={project}, application={application}, stage={stage}, key={key}")
         found = locate_ssm_parameter_in_context_hierachy(project, application, stage, key, prefix=self.get_prefix())
         if not found:
@@ -92,14 +92,14 @@ class AwsSsmSecretProvider(SecretProvider):
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found['Name']}")
         response = get_ssm_secret_history(found['Name'], decrypt)
-        secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        secrets = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         if revision is None:
             ### get the latest revision
             result = {
                     'RevisionId': str(secrets[0]['Version']),
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': decode_nulls(secrets[0]['Value']),
+                    'Value': secrets[0]['Value'],
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -114,7 +114,7 @@ class AwsSsmSecretProvider(SecretProvider):
                     'RevisionId': str(secrets[0]['Version']),
                     'Date': secrets[0]['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                     'Key': key, 
-                    'Value': decode_nulls(secrets[0]['Value']),
+                    'Value': secrets[0]['Value'],
                     'Scope': found['Scope'],
                     'Origin': found['Origin'],
                     'Path': found['Name'],
@@ -134,13 +134,13 @@ class AwsSsmSecretProvider(SecretProvider):
                 raise DSOException(f"Parameter '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM secret: path={found['Name']}")
         response = get_ssm_secret_history(found['Name'], decrypt)
-        secrets = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        secrets = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         result = { "Revisions":
             [{
                 'RevisionId': str(secret['Version']),
                 'Date': secret['LastModifiedDate'].strftime('%Y/%m/%d-%H:%M:%S'),
                 # 'Key': key,
-                'Value': decode_nulls(secret['Value']),
+                'Value': secret['Value'],
                 # 'Scope': found['Scope'],
                 # 'Origin': found['Origin'],
                 'User': secret['LastModifiedUser'],
