@@ -107,7 +107,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                 raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM template: path={found['Name']}")
         response = get_ssm_template_history(found['Name'])
-        templates = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        templates = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         if revision is None:
             ### get the latest revision
             result = {
@@ -118,7 +118,6 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    # 'Contents': unescape_curly_brackets(templates[0]['Value']),
                     'Contents': templates[0]['Value'],
                     }
         else:
@@ -134,7 +133,6 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    # 'Contents': unescape_curly_brackets(templates[0]['Value']),
                     'Contents': templates[0]['Value'],
                     }
 
@@ -152,7 +150,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                 raise DSOException(f"Template '{key}' not found in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM template: path={found['Name']}")
         response = get_ssm_parameter_history(found['Name'])
-        parameters = sorted(response['Parameters'], key=lambda x: x['Version'], reverse=True)
+        parameters = sorted(response['Parameters'], key=lambda x: int(x['Version']), reverse=True)
         if include_contents:
             result = { "Revisions":
                 [{
@@ -163,7 +161,8 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     # 'Origin': found['Origin'],
                     'User': template['LastModifiedUser'],
                     # 'Path': found['Name'],
-                    'Contents': unescape_curly_brackets(template['Value']),
+                    'Contents': templates[0]['Value'],
+
                 } for template in parameters]
             }
         else:
