@@ -3,6 +3,9 @@ import re
 from .constants import *
 from .exceptions import DSOException
 
+
+REGEX_PATTERN = r"^([a-zA-Z][a-zA-Z0-9]+)/?([0-9])?$"
+
 class Stages():
 
     # @staticmethod
@@ -11,11 +14,13 @@ class Stages():
 
     @staticmethod
     def raw_parse(stage):
-        if not stage: 
-            raise DSOException(MESSAGES['InvalidStage'].format(stage, REGEX_PATTERNS['stage']))
-        m = re.match(REGEX_PATTERNS['stage'], stage)
+        if not stage:
+            import traceback
+            traceback.print_stack() 
+            raise DSOException(MESSAGES['Stage'].format(stage, REGEX_PATTERN))
+        m = re.match(REGEX_PATTERN, stage)
         if m is None:
-            raise DSOException(MESSAGES['InvalidStage'].format(stage, REGEX_PATTERNS['stage']))
+            raise DSOException(MESSAGES['InvalidStage'].format(stage, REGEX_PATTERN))
         stage = m.groups()[0]
         env = int(m.groups()[1]) if len(m.groups()) > 1 and m.groups()[1] else ''
         return stage, env
@@ -47,6 +52,7 @@ class Stages():
 
     @staticmethod
     def shorten(stage):
+        if not stage: return 'default'
         stage, env = Stages.parse_normalized(stage)
         if env == 0:
             return stage
